Classes and summary methods related to copula model fitting.
Objects can be created by calls to fitCopula or
fitMvdc, respectively or to their summary methods.
The “mother class”, "fittedMV" has the slots
estimate:numeric, the estimated parameters.
var.est:numeric, variance matrix estimate of
the parameter estimator. See note below.
loglik:numeric, log likelihood evaluated at
the maximizer.
nsample:numeric, integer representing the
sample size.
method:character, method of estimation.
fitting.stats:a list, currently
containing the numeric convergence code from
optim, the counts, message, and all
the control arguments explicitly passed to
optim.
In addition, the "fitCopula" class has a slot
whereas the "fitMvdc" has
Classes "fitCopula" and "fitMvdc" extend class
"fittedMV", directly.
Genest, C., Ghoudi, K., and Rivest, L.-P. (1995). A semiparametric estimation procedure of dependence parameters in multivariate families of distributions. Biometrika 82, 543--552.